@@ -8,5 +8,6 @@ use DateTime::Natural::Parse qw(natural_parse);
 while (1) {
     print 'Input date string: ';
     chomp(my $input = <STDIN>);
-    print natural_parse($input);
+    my $dt = natural_parse($input);
+    printf("%02s.%02s.%4s %02s:%02s\n", $dt->day, $dt->month, $dt->year, $dt->hour, $dt->min);
 }
